Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7776)

Unified Diff: chrome/browser/ui/search/toolbar_search_animator_observer.h

Issue 10944016: Switch SearchTabHelper to use WebContentsUserData. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/search/toolbar_search_animator_observer.h
diff --git a/chrome/browser/ui/search/toolbar_search_animator_observer.h b/chrome/browser/ui/search/toolbar_search_animator_observer.h
index 3c1503885ed3bfa93958038669a32d434f668e6d..82b825a32e68fd9fe7a35b6d2375c05c526f6302 100644
--- a/chrome/browser/ui/search/toolbar_search_animator_observer.h
+++ b/chrome/browser/ui/search/toolbar_search_animator_observer.h
@@ -5,7 +5,9 @@
#ifndef CHROME_BROWSER_UI_SEARCH_TOOLBAR_SEARCH_ANIMATOR_OBSERVER_H_
#define CHROME_BROWSER_UI_SEARCH_TOOLBAR_SEARCH_ANIMATOR_OBSERVER_H_
-class TabContents;
+namespace content {
+class WebContents;
+}
namespace chrome {
namespace search {
@@ -20,11 +22,11 @@ class ToolbarSearchAnimatorObserver {
// Called when toolbar gradient background animation is canceled and jumps to
// the end state.
// If animation is canceled because the active tab is deactivated or detached
// or closing, |tab_contents| contains the tab's contents.
// Otherwise, if animation is canceled because of mode change, |tab_contents|
// is NULL.
virtual void OnToolbarBackgroundAnimatorCanceled(
- TabContents* tab_contents) = 0;
+ content::WebContents* web_contents) = 0;
// Called when toolbar separator visibility has changed.
virtual void OnToolbarSeparatorChanged() = 0;
@@ -20,11 +22,11 @@ class ToolbarSearchAnimatorObserver {
// the end state.
// If animation is canceled because the active tab is deactivated or detached
- // or closing, |tab_contents| contains the tab's contents.
- // Otherwise, if animation is canceled because of mode change, |tab_contents|
+ // or closing, |web_contents| contains the tab's contents.
+ // Otherwise, if animation is canceled because of mode change, |web_contents|
// is NULL.
virtual void OnToolbarBackgroundAnimatorCanceled(

Powered by Google App Engine
This is Rietveld 408576698